unit main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, mwi_sd, StdCtrls, ExtCtrls, Buttons, Spin;

type
  TForm1 = class(TForm)
    mwiSmartDongle1: TmwiSmartDongle;
    Shape1: TShape;
    btnCheck: TBitBtn;
    btnSetLED: TBitBtn;
    RadioGroup1: TRadioGroup;
    Bevel1: TBevel;
    Bevel2: TBevel;
    Memo1: TMemo;
    Bevel3: TBevel;
    Label1: TLabel;
    BitBtn3: TBitBtn;
    Label2: TLabel;
    SpinEdit1: TSpinEdit;
    Bevel4: TBevel;
    btnEepromSize: TBitBtn;
    Bevel5: TBevel;
    btnRead: TBitBtn;
    btnWrite: TBitBtn;
    ReadEdit: TEdit;
    Label3: TLabel;
    ReadPage: TSpinEdit;
    Label4: TLabel;
    WritePage: TSpinEdit;
    WriteEdit: TEdit;
    Bevel6: TBevel;
    btnVersion: TBitBtn;
    VersionMemo: TMemo;
    radioType: TRadioGroup;
    procedure btnCheckClick(Sender: TObject);
    procedure btnSetLEDClick(Sender: TObject);
    procedure BitBtn3Click(Sender: TObject);
    procedure mwiSmartDongle1ThreadError(ErrorCode: Integer;
      ErrorMsg: String);
    procedure mwiSmartDongle1ThreadSuccess;
    procedure btnEepromSizeClick(Sender: TObject);
    procedure btnWriteClick(Sender: TObject);
    procedure btnReadClick(Sender: TObject);
    procedure btnVersionClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

type
  TDataType = (DTAnsi, DTWide, DTString, DTDouble, DTInteger);

procedure TForm1.btnCheckClick(Sender: TObject);
begin

   Memo1.Text := 'Checking dongle status...';
   Application.ProcessMessages();


   try
      // Using the Authenticate method to check for dongle presence.
      // Could also just attempt a read or write.
      mwiSmartDongle1.Authenticate();

      Shape1.Brush.Color := clLime;
      Memo1.Lines.Add('Dongle is present.');
   except
      on E: ESDError do
      begin
         Memo1.Lines.Add(E.Message + ' Error Code = ' + IntToStr( E.ErrorCode ));
         Shape1.Brush.Color := clRed;
      end

      else
         Shape1.Brush.Color := clRed;
   end;
end;

procedure TForm1.btnSetLEDClick(Sender: TObject);
begin
   // Set LED color.
   case RadioGroup1.ItemIndex of
      0: mwiSmartDongle1.SetLEDColor( sdGreen );
      1: mwiSmartDongle1.SetLEDColor( sdRed );
      2: mwiSmartDongle1.SetLEDColor( sdNone );
   end;
end;

procedure TForm1.BitBtn3Click(Sender: TObject);
begin
   Shape1.Brush.Color := clWhite;

   // This button is used as a toggle type button so if ThreadActive = true then
   // shut it down.
   if( mwiSmartDongle1.ThreadActive ) then
   begin
      mwiSmartDongle1.ThreadActive := false;
      BitBtn3.Caption := 'Start Background Check';
      BitBtn3.Font.Color := clGreen;

      // Re-enable buttons
      btnCheck.Enabled := true;
      btnSetLED.Enabled := true;
      btnEepromSize.Enabled := true;
      btnRead.Enabled := true;
      btnWrite.Enabled := true;
      btnVersion.Enabled := true;
   end


   // Otherwise, activate the background thread.
   else
   begin

      mwiSmartDongle1.ThreadInterval := SpinEdit1.Value;

      Memo1.Text := 'Performing dongle status check in the background every ' +
                    IntToStr( mwiSmartDongle1.ThreadInterval ) + ' seconds...';


      // Start the background thread, Key1 and Key2 properties must be set.
      mwiSmartDongle1.ThreadActive := true;

      BitBtn3.Caption := 'Stop Background Check';
      BitBtn3.Font.Color := clRed;

      // don't allow other functions while background process is running since
      // usk is not thread safe.
      btnCheck.Enabled := false;
      btnSetLED.Enabled := false;
      btnEepromSize.Enabled := false;
      btnRead.Enabled := false;
      btnWrite.Enabled := false;
      btnVersion.Enabled := false;
   end;
end;



procedure TForm1.mwiSmartDongle1ThreadError(ErrorCode: Integer;
  ErrorMsg: String);
begin
   Memo1.Lines.Add('Dongle is not present. Message: ' + ErrorMsg +
                   ' Error Code: ' + IntToStr( ErrorCode ));
   Shape1.Brush.Color := clRed;
end;



procedure TForm1.mwiSmartDongle1ThreadSuccess;
begin
   Memo1.Lines.Add('Thread check ( ' + TimeToStr( NOW ) + ') - dongle is present.');
   Shape1.Brush.Color := clLime;
end;

procedure TForm1.btnEepromSizeClick(Sender: TObject);
var
  size: Integer;
begin
   size := mwiSmartDongle1.GetEepromSize;
   Memo1.Text := 'Eeprom size (available dongle memory for reading and writing) is ' +
                 IntToStr( size ) + ' bytes.';
end;

procedure TForm1.btnWriteClick(Sender: TObject);
var
  page: Integer;
  value: String;
  dbl: Double;
  int: Integer;
begin
  page := WritePage.Value;
  value := WriteEdit.Text;

  case TDataType(radioType.ItemIndex) of
    DTAnsi: mwiSmartDongle1.WriteAnsiString(page, AnsiString(value));
    DTWide: mwiSmartDongle1.WriteWideString(page, WideString(value));
    DTString: mwiSmartDongle1.WriteString(page, value);
    DTDouble:
    begin
      if TryStrToFloat(value, dbl) then
        mwiSmartDongle1.WriteDouble(page, dbl)
      else
        Memo1.Text := 'The value "' + value + '" is not a valid Double.';
    end;
    DTInteger:
    begin
      if TryStrToInt(value, int) then
        mwiSmartDongle1.WriteInteger(page, int)
      else
        Memo1.Text := 'The value "' + value + '" is not a valid Integer.';
    end;
  end;
end;

procedure TForm1.btnReadClick(Sender: TObject);
var
  page: Integer;
  value: String;
begin
  value := '';
  ReadEdit.Text := '';
  Application.ProcessMessages;

  page := WritePage.Value;

  case TDataType(radioType.ItemIndex) of
    DTAnsi: value := mwiSmartDongle1.ReadAnsiString(page);
    DTWide: value := mwiSmartDongle1.ReadWideString(page);
    DTString: value := mwiSmartDongle1.ReadString(page);
    DTDouble: value := FloatToStr(mwiSmartDongle1.ReadDouble(page));
    DTInteger: value := IntToStr(mwiSmartDongle1.ReadInteger(page));
  end;

  ReadEdit.Text := value;
end;

(*
procedure TForm1.btnWriteClick(Sender: TObject);
var
   Buffer: array [ 0..EEPROM_PAGE_SIZE - 1 ] of byte;
begin
   try
      Screen.Cursor := crHourGlass;

      ZeroMemory( @Buffer, EEPROM_PAGE_SIZE );
      CopyMemory( @Buffer, PChar( WriteEdit.Text ), Length( WriteEdit.Text ) );

      // The most straight forward approach to writing to the EEPROM is to write
      // one page at a time. It is possible however to write multiple pages at a time,
      // just make sure that the buffer size is a multiple of the page size.
      mwiSmartDongle1.Write( WritePage.Value * EEPROM_PAGE_SIZE,
                             PAnsiChar( AnsiString(WriteEdit.Text) ),//@Buffer,
                             EEPROM_PAGE_SIZE );
   finally
      Screen.Cursor := crDefault;
   end;
end;

procedure TForm1.btnReadClick(Sender: TObject);
var
   Buffer: array [ 0..EEPROM_PAGE_SIZE - 1 ] of byte;
begin
   try
      Screen.Cursor := crHourGlass;

      ZeroMemory( @Buffer, EEPROM_PAGE_SIZE );

      // The most straight forward approach to reading from the EEPROM is to read
      // one page at a time. It is possible however to read multiple pages at a time,
      // just make sure that the buffer size is a multiple of the page size.
      mwiSmartDongle1.Read( ReadPage.Value * EEPROM_PAGE_SIZE,
                            @Buffer,
                            EEPROM_PAGE_SIZE );

      ReadEdit.Text := PChar( @Buffer );
   finally
      Screen.Cursor := crDefault;
   end;
end;
*)


procedure TForm1.btnVersionClick(Sender: TObject);
begin
   with mwiSmartDongle1.Version do
   begin
      VersionMemo.Lines.Add( 'Major: ' + IntToStr( dwMajorVersion ) );
      VersionMemo.Lines.Add( 'Minor: ' + IntToStr( dwMinorVersion ) );
      VersionMemo.Lines.Add( 'Build: ' + IntToStr( dwBuildNumber ) );
      VersionMemo.Lines.Add( 'Platform: ' + IntToStr( dwPlatformID ) );
   end;
end;

end.

