/*
   smartdongle.h for SmartDongle API version 3.2


   www.smartdongle.com

   MicroWorks, Inc.
   2808 North Cole Road
   Boise, ID 83704
*/

#ifndef _DEFINED_2A39393E_C414_4F94_B623_3FBCE5A8190F
#define _DEFINED_2A39393E_C414_4F94_B623_3FBCE5A8190F


#ifndef _WINDOWS_
   #include <Windows.h>
#endif

/*
   Maximum string length returned from GetErrorString()
*/
#define QTS_ERROR_STRING_LENGTH_MAX 128

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*
   Given the correct keys, P1 and P2, will place the dongle into
   the enabled state and read EEPROM into buffer.

   Valid address is 0 to 32431

   Note: Refer to sd_uskerr.h for returned errors.
*/
   int SmartDongleRead (
      unsigned __int64 P1,
      unsigned __int64 P2,
      unsigned int address,
      unsigned char *buffer,
      int size);

/*
   Given the correct keys, P1 and P2, will place the dongle into
   the enabled state and buffer into EEPROM.

   Valid address is 0 to 32431

   Note: Refer to sd_uskerr.h for returned errors.
*/
   int SmartDongleWrite(
      unsigned __int64 P1,
      unsigned __int64 P2,
      unsigned int address,
      unsigned char *buffer,
      int size);

/*
   SmartDongle reboot.
*/
   int SmartDongleReset (void);

/*
   LED Control.
*/
   int SmartDongleLedGreen(void);
   int SmartDongleLedRed(void);
   int SmartDongleLedOff(void);

/*
   User EPROM memory encryption control - Firmware >=v1.42

   Modes:

   0 - User EPROM memory space protected by strong (AES) encryption
   1 - User EPROM memory space is unencrypted
   2 - User EPROM memory space protected by fast encryption
*/
   int SmartDongleWriteCryptMode(
      unsigned __int64 P1,
      unsigned __int64 P2,
      unsigned char mode);

/*
   Read current encryption mode.
*/
   int SmartDongleReadCryptMode(unsigned char *mode);

/*
   Attempt to locate correct SmartDongle by iterating through the device list,
   returning serial number in sn, if sn is non-NULL.
   User must allocate CP2_SERIALNUM_LENGTH+1 for returned serial number string.
*/
   unsigned int SmartDongleGetEpromSize(
      unsigned __int64 P1,
      unsigned __int64 P2);

/*
   User must allocate CP2_SERIALNUM_LENGTH+1 sn buffer
*/
   int SmartDongleGetSerialNumber (char *sn);

/*
   For SmartDongle >=v1.50 using >= v2.3 driver only.
   This will configure the SmartDongle for use with
   the 2.3 driver only.

   Caution: This configuration is permanent. SmartDongle
            must be sent back to the manufacturer to be
            reset to use the older drivers (<= v2.2.0).
*/
   int SmartDongleSetStrict (void);

/*
   Return error description string corresponding to error code.
   User must allocate string size of QTS_ERROR_STRING_LENGTH_MAX
*/
   void SmartDongleGetErrorString (char *errorString, int error);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

#endif /* _DEFINED_2A39393E_C414_4F94_B623_3FBCE5A8190F */
